@@ -1,12 +1,11 @@
-#ifndef READXL_XLSXCELL_
-#define READXL_XLSXCELL_
+#pragma once
 
-#include <Rcpp.h>
-#include "rapidxml.h"
 #include "ColSpec.h"
 #include "XlsxString.h"
 #include "utils.h"
 
+#include "rapidxml/rapidxml.h"
+
 // Key reference for understanding the structure of the XML is
 // ECMA-376 (http://www.ecma-international.org/publications/standards/Ecma-376.htm)
 // Section and page numbers below refer to the 5th edition October 2016
@@ -55,8 +54,8 @@ public:
 
   void inferType(const StringSet& na,
                  const bool trimWs,
-                 const std::vector<std::string>& stringTable,
-                 const std::set<int>& dateFormats) {
+                 const std::set<int>& dateFormats,
+                 const std::vector<std::string>& stringTable) {
     // 1. Review of Excel's declared cell types, then
     // 2. Summary of how Excel's cell types map to our CellType enum
     //
@@ -178,12 +177,12 @@ public:
       return;
     }
 
-    Rcpp::warning("Unrecognized cell type at %s: '%s'",
-                  cellPosition(row(), col()), t->value());
+    cpp11::warning("Unrecognized cell type at %s: '%s'",
+                  cellPosition(row(), col()).c_str(), t->value());
   }
 
-  std::string asStdString(const std::vector<std::string>& stringTable,
-                          const bool trimWs) const {
+  std::string asStdString(const bool trimWs,
+                          const std::vector<std::string>& stringTable) const {
     if (cell_ == NULL) {
       return "";
     }
@@ -232,14 +231,15 @@ public:
     }
 
     default:
-      Rcpp::warning("Unrecognized cell type at %s", cellPosition(row(), col()));
+      cpp11::warning("Unrecognized cell type at %s", cellPosition(row(), col()).c_str());
       return "";
   }
   }
 
-  Rcpp::RObject asCharSxp(const std::vector<std::string>& stringTable,
-                          const bool trimWs) const {
-    std::string out_string = asStdString(stringTable, trimWs);
+  cpp11::sexp asCharSxp(
+      const bool trimWs,
+      const std::vector<std::string>& stringTable) const {
+    std::string out_string = asStdString(trimWs, stringTable);
     return out_string.empty() ? NA_STRING : Rf_mkCharCE(out_string.c_str(), CE_UTF8);
   }
 
@@ -260,7 +260,7 @@ public:
     }
 
     default:
-      Rcpp::warning("Unrecognized cell type at %s", cellPosition(row(), col()));
+      cpp11::warning("Unrecognized cell type at %s", cellPosition(row(), col()).c_str());
       return NA_LOGICAL;
     }
   }
@@ -282,7 +282,7 @@ public:
     }
 
     default:
-      Rcpp::warning("Unrecognized cell type at %s", cellPosition(row(), col()));
+      cpp11::warning("Unrecognized cell type at %s", cellPosition(row(), col()).c_str());
       return NA_REAL;
     }
   }
@@ -304,7 +304,7 @@ public:
     }
 
     default:
-      Rcpp::warning("Unrecognized cell type at %s", cellPosition(row(), col()));
+      cpp11::warning("Unrecognized cell type at %s", cellPosition(row(), col()).c_str());
       return NA_REAL;
     }
   }
@@ -315,7 +315,7 @@ private:
                               const std::vector<std::string>& stringTable) const {
     int id = atoi(val);
     if (id < 0 || id >= (int) stringTable.size()) {
-      Rcpp::warning("Invalid string id at %s: %i", cellPosition(row(), col()), id);
+      cpp11::warning("Invalid string id at %s: %i", cellPosition(row(), col()).c_str(), id);
       return "";
     }
     const std::string& string = stringTable.at(id);
@@ -323,5 +323,3 @@ private:
   }
 
 };
-
-#endif
