@@ -1,20 +1,17 @@
-#include <Rcpp.h>
-
 #include "zip.h"
-#include "rapidxml_print.h"
 
-using namespace Rcpp;
+#include "rapidxml/rapidxml_print.h"
 
-Function readxl(const std::string& fun){
-  Environment env = Environment::namespace_env("readxl");
-  return env[fun];
-}
+#include "cpp11/as.hpp"
+#include "cpp11/function.hpp"
+#include "cpp11/raws.hpp"
+#include "cpp11/sexp.hpp"
 
 std::string zip_buffer(const std::string& zip_path,
                        const std::string& file_path) {
-  Rcpp::Function zip_buffer = readxl("zip_buffer");
+  cpp11::function zip_buffer = cpp11::package("readxl")["zip_buffer"];
 
-  Rcpp::RawVector xml = Rcpp::as<Rcpp::RawVector>(zip_buffer(zip_path, file_path));
+  cpp11::raws xml(zip_buffer(zip_path, file_path));
   std::string buffer(RAW(xml), RAW(xml) + xml.size());
   buffer.push_back('\0');
 
@@ -23,10 +20,9 @@ std::string zip_buffer(const std::string& zip_path,
 
 bool zip_has_file(const std::string& zip_path,
                   const std::string& file_path) {
-  Rcpp::Function zip_has_file = readxl("zip_has_file");
-
-  LogicalVector res = wrap<LogicalVector>(zip_has_file(zip_path, file_path));
-  return res[0];
+  cpp11::function zip_has_file = cpp11::package("readxl")["zip_has_file"];
+  cpp11::sexp out = zip_has_file(zip_path, file_path);
+  return cpp11::as_cpp<bool>(out);
 }
 
 std::string xml_print(std::string xml) {
@@ -41,10 +37,10 @@ std::string xml_print(std::string xml) {
   return s;
 }
 
-// [[Rcpp::export]]
+[[cpp11::register]]
 void zip_xml(const std::string& zip_path,
              const std::string& file_path) {
 
   std::string buffer = zip_buffer(zip_path, file_path);
-  Rcout << xml_print(buffer);
+  Rprintf("%s", xml_print(buffer).c_str());
 }
