@@ -1,38 +1,34 @@
-context("Column types")
-
 test_that("illegal col_types are rejected", {
-  expect_error(
+  expect_snapshot(
+    error = TRUE,
     read_excel(
       test_sheet("types.xlsx"),
       col_types = c("foo", "numeric", "text", "bar")
-    ),
-    "Illegal column type"
+    )
   )
 })
 
 test_that("request for 'blank' col type gets deprecation message and fix", {
-  expect_message(
+  expect_snapshot(
     read_excel(
       test_sheet("types.xlsx"),
       col_types = rep_len(c("blank", "text"), length.out = 5)
-    ),
-    "`col_type = \"blank\"` deprecated. Use \"skip\" instead.",
-    fixed = TRUE
+    )
   )
 })
 
 test_that("invalid col_types are rejected", {
-  expect_error(
+  expect_snapshot(
+    error = TRUE,
     read_excel(test_sheet("types.xlsx"), col_types = character()),
-    "length(col_types) > 0 is not TRUE", fixed = TRUE
   )
-  expect_error(
-    read_excel(test_sheet("types.xlsx"), col_types = 1:3),
-    "is.character(col_types) is not TRUE", fixed = TRUE
+  expect_snapshot(
+    error = TRUE,
+    read_excel(test_sheet("types.xlsx"), col_types = 1:3)
   )
-  expect_error(
+  expect_snapshot(
+    error = TRUE,
     read_excel(test_sheet("types.xlsx"), col_types = c(NA, "text", "numeric")),
-    "!anyNA(col_types) is not TRUE", fixed = TRUE
   )
 })
 
@@ -41,12 +37,12 @@ test_that("col_types can be specified", {
     test_sheet("iris-excel-xlsx.xlsx"),
     col_types = c("numeric", "text", "numeric", "numeric", "text")
   )
-  expect_is(df[[2]], "character")
+  expect_true(is.character(df[[2]]))
   df <- read_excel(
     test_sheet("iris-excel-xls.xls"),
     col_types = c("numeric", "text", "numeric", "numeric", "text")
   )
-  expect_is(df[[2]], "character")
+  expect_true(is.character(df[[2]]))
 })
 
 test_that("col_types are recycled", {
@@ -58,21 +54,21 @@ test_that("col_types are recycled", {
 
 test_that("types guessed correctly [xlsx]", {
   types <- read_excel(test_sheet("types.xlsx"), sheet = "guess_me")
-  expect_is(types$blank, "logical")
-  expect_is(types$boolean, "logical")
-  expect_is(types$date, "POSIXct")
-  expect_is(types$numeric, "numeric")
-  expect_is(types$text, "character")
+  expect_true(is.logical(types$blank))
+  expect_true(is.logical(types$boolean))
+  expect_s3_class(types$date, "POSIXct")
+  expect_true(is.numeric(types$numeric))
+  expect_true(is.character(types$text))
   expect_true(all(vapply(types, function(x) is.na(x[3]), logical(1))))
 })
 
 test_that("types guessed correctly [xls]", {
   types <- read_excel(test_sheet("types.xls"), sheet = "guess_me")
-  expect_is(types$blank, "logical")
-  expect_is(types$boolean, "logical")
-  expect_is(types$date, "POSIXct")
-  expect_is(types$numeric, "numeric")
-  expect_is(types$text, "character")
+  expect_true(is.logical(types$blank))
+  expect_true(is.logical(types$boolean))
+  expect_s3_class(types$date, "POSIXct")
+  expect_true(is.numeric(types$numeric))
+  expect_true(is.character(types$text))
   expect_true(all(vapply(types, function(x) is.na(x[3]), logical(1))))
 })
 
@@ -82,45 +78,43 @@ test_that("we can specify some col_types and guess others", {
 
   df <- read_excel(test_sheet("types.xlsx"), col_types = ctypes)
   cls <- vapply(df, function(x) class(x)[1], character(1))
-  expect_equivalent(cls, exp_cls)
+  expect_equal(cls, exp_cls, ignore_attr = TRUE)
 
   df <- read_excel(test_sheet("types.xls"), col_types = ctypes)
   cls <- vapply(df, function(x) class(x)[1], character(1))
-  expect_equivalent(cls, exp_cls)
+  expect_equal(cls, exp_cls, ignore_attr = TRUE)
 })
 
 test_that("guess_max is honored for col_types", {
-  expect_warning(
+  expect_snapshot(
     types <- read_excel(
       test_sheet("types.xlsx"),
       sheet = "guess_max",
       guess_max = 2
-    ),
-    "Expecting numeric",
-    all = TRUE
+    )
   )
+
   expect_identical(types$string_in_row_3, c(1, 2, NA))
-  expect_warning(
+
+  expect_snapshot(
     types <- read_excel(
       test_sheet("types.xls"),
       sheet = "guess_max",
       guess_max = 2
-    ),
-    "Expecting numeric",
-    all = TRUE
+    )
   )
+
   expect_identical(types$string_in_row_3, c(1, 2, NA))
 })
 
 test_that("wrong length col types generates error", {
-  err_msg <- "Sheet 1 has 5 columns, but `col_types` has length 2."
-  expect_error(
-    read_excel(test_sheet("iris-excel-xlsx.xlsx"), col_types = c("numeric", "text")),
-    err_msg
+  expect_snapshot(
+    error = TRUE,
+    read_excel(test_sheet("iris-excel-xlsx.xlsx"), col_types = c("numeric", "text"))
   )
-  expect_error(
-    read_excel(test_sheet("iris-excel-xls.xls"), col_types = c("numeric", "text")),
-    err_msg
+  expect_snapshot(
+    error = TRUE,
+    read_excel(test_sheet("iris-excel-xls.xls"), col_types = c("numeric", "text"))
   )
 })
 
@@ -158,17 +152,23 @@ test_that("setting `na` works in list columns [xls]", {
 ## values for subsequent cells holding numeric data
 ## refines fix initiated in #398
 test_that("numeric is correctly coerced to logical [xlsx]", {
-  expect_warning(
-    df <- read_xlsx(test_sheet("missing-values-xlsx.xlsx"), guess_max = 0)
+  expect_snapshot(
+    df <- read_xlsx(test_sheet("missing-values-xlsx.xlsx"),
+      guess_max = 0
+    )
   )
+
   expect_identical(df$z, c(NA, TRUE, TRUE))
   expect_equal(sum(df$z, na.rm = TRUE), 2)
 })
 
 test_that("numeric is correctly coerced to logical [xls]", {
-  expect_warning(
-    df <- read_xls(test_sheet("missing-values-xls.xls"), guess_max = 0)
+  expect_snapshot(
+    df <- read_xls(test_sheet("missing-values-xls.xls"),
+      guess_max = 0
+    )
   )
+
   expect_identical(df$z, c(NA, TRUE, TRUE))
   expect_equal(sum(df$z, na.rm = TRUE), 2)
 })
